@@ -30,6 +30,9 @@
 /*******************************************************************************/
 #include "weather-common.h"
 /*******************************************************************************/
+#ifdef OS2009
+gchar *picker_print_func (HildonTouchSelector *selector, gpointer userdata);
+#endif
 void widget_styles_save(GtkWidget *window);
 void weather_simple_window_settings(gpointer user_data);
 GtkWidget* create_and_fill_stations_buttons(GtkWidget *main_table);
@@ -43,7 +46,7 @@ void choose_button_handler(GtkWidget *button, GdkEventButton *event, gpointer us
 void save_station(GtkWidget *window);
 void widget_style_setup_button_handler(GtkWidget *button, GdkEventButton *event,
                                     gpointer user_data);
-GtkWidget* create_button(gchar* name, gchar* value, gchar* button_name, gchar* parameter_name, GtkWidget* widget);
+GtkWidget* create_button(gchar* name, gchar* value, gchar* button_name, gchar* parameter_name, GtkWidget* widget, GtkListStore *list);
 void create_and_fill_units_box(GtkWidget *main_table);
 void create_and_fill_update_box(GtkWidget *main_table);
 void create_and_fill_widget_style_box(GtkWidget *main_table);
@@ -57,5 +60,8 @@ void manual_button_handler(GtkWidget *window, GdkEventButton *event, gpointer us
 void gps_button_handler(GtkWidget *window, GdkEventButton *event, gpointer user_data);
 void delete_station_from_user_list(gchar *station_selected, gpointer user_data);
 void check_current_connection(void);
+void free_list(GSList *list);
+void clear_station(GtkWidget *window);
+void changing_of_location (GtkWidget *button, gpointer user_data);
 /*******************************************************************************/
 #endif
