@@ -613,9 +613,11 @@ create_button_with_2_line_text(const gchar *first_line_text, const gchar *second
               *button = NULL;
 #if defined OS2009
   button = hildon_button_new_with_text (HILDON_SIZE_FINGER_HEIGHT | HILDON_SIZE_AUTO_WIDTH,
-                    HILDON_BUTTON_ARRANGEMENT_VERTICAL,
+                     HILDON_BUTTON_ARRANGEMENT_VERTICAL,
                      first_line_text,
                      second_line_text);
+  hildon_button_set_alignment(button,0,0.5,0,1);
+  hildon_button_set_style(button, HILDON_BUTTON_STYLE_PICKER);
 #else
     button = gtk_button_new();
 
@@ -643,6 +645,29 @@ create_button_with_2_line_text(const gchar *first_line_text, const gchar *second
     return button;
 }
 /*******************************************************************************/
+#ifdef ENABLE_BROWSER_INTERFACE
+gboolean
+browser_url(gchar *url) {
+
+  osso_return_t ret;
+#ifdef DEBUGFUNCTIONCALL
+    START_FUNCTION;
+#endif
+
+  ret = osso_rpc_run_with_defaults(app->osso, "osso_browser",
+          OSSO_BROWSER_OPEN_NEW_WINDOW_REQ, NULL,
+          DBUS_TYPE_STRING, url,
+          DBUS_TYPE_BOOLEAN, FALSE, DBUS_TYPE_INVALID);
+
+  if(ret != OSSO_OK){
+    fprintf(stderr,"Unable to display URL in browser!");
+    return FALSE;
+  }
+
+  return TRUE;
+}
+#endif
+/*******************************************************************************/
 /* For debugging   */
 /*
 void write_log(char *string)
